/*
Copyright 2020 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1

import (
	"time"

	v1 "github.com/zalando-incubator/kube-metrics-adapter/pkg/apis/zalando.org/v1"
	scheme "github.com/zalando-incubator/kube-metrics-adapter/pkg/client/clientset/versioned/scheme"
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// ScheduledScalingsGetter has a method to return a ScheduledScalingInterface.
// A group's client should implement this interface.
type ScheduledScalingsGetter interface {
	ScheduledScalings(namespace string) ScheduledScalingInterface
}

// ScheduledScalingInterface has methods to work with ScheduledScaling resources.
type ScheduledScalingInterface interface {
	Create(*v1.ScheduledScaling) (*v1.ScheduledScaling, error)
	Update(*v1.ScheduledScaling) (*v1.ScheduledScaling, error)
	Delete(name string, options *metav1.DeleteOptions) error
	DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
	Get(name string, options metav1.GetOptions) (*v1.ScheduledScaling, error)
	List(opts metav1.ListOptions) (*v1.ScheduledScalingList, error)
	Watch(opts metav1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.ScheduledScaling, err error)
	ScheduledScalingExpansion
}

// scheduledScalings implements ScheduledScalingInterface
type scheduledScalings struct {
	client rest.Interface
	ns     string
}

// newScheduledScalings returns a ScheduledScalings
func newScheduledScalings(c *ZalandoV1Client, namespace string) *scheduledScalings {
	return &scheduledScalings{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the scheduledScaling, and returns the corresponding scheduledScaling object, and an error if there is any.
func (c *scheduledScalings) Get(name string, options metav1.GetOptions) (result *v1.ScheduledScaling, err error) {
	result = &v1.ScheduledScaling{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("scheduledscalings").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of ScheduledScalings that match those selectors.
func (c *scheduledScalings) List(opts metav1.ListOptions) (result *v1.ScheduledScalingList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1.ScheduledScalingList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("scheduledscalings").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested scheduledScalings.
func (c *scheduledScalings) Watch(opts metav1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("scheduledscalings").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a scheduledScaling and creates it.  Returns the server's representation of the scheduledScaling, and an error, if there is any.
func (c *scheduledScalings) Create(scheduledScaling *v1.ScheduledScaling) (result *v1.ScheduledScaling, err error) {
	result = &v1.ScheduledScaling{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("scheduledscalings").
		Body(scheduledScaling).
		Do().
		Into(result)
	return
}

// Update takes the representation of a scheduledScaling and updates it. Returns the server's representation of the scheduledScaling, and an error, if there is any.
func (c *scheduledScalings) Update(scheduledScaling *v1.ScheduledScaling) (result *v1.ScheduledScaling, err error) {
	result = &v1.ScheduledScaling{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("scheduledscalings").
		Name(scheduledScaling.Name).
		Body(scheduledScaling).
		Do().
		Into(result)
	return
}

// Delete takes name of the scheduledScaling and deletes it. Returns an error if one occurs.
func (c *scheduledScalings) Delete(name string, options *metav1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("scheduledscalings").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *scheduledScalings) DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("scheduledscalings").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched scheduledScaling.
func (c *scheduledScalings) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.ScheduledScaling, err error) {
	result = &v1.ScheduledScaling{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("scheduledscalings").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
